@@ -6,5 +6,7 @@ DROP OPERATOR = ( name[], name[] );
 DROP FUNCTION namearray_eq( name[], name[] );
 DROP CAST (name[] AS text);
 DROP FUNCTION namearray_text(name[]);
+DROP CAST (text[] AS text);
+DROP FUNCTION textarray_text(text[]);
 DROP CAST (boolean AS char(1);
 DROP FUNCTION booltext(boolean);
